@@ -417,11 +417,11 @@ class TestTranslateSearch(BaseTestCase):
         param('en', 'January 3, 2017 - February 1st',
               [('January 3, 2017', datetime.datetime(2017, 1, 3, 0, 0)),
                ('February 1st', datetime.datetime(2017, 2, 1, 0, 0))]),
-        param('en', '2014 was good! November was excellent!'
+        param('en', '2014 was good! October was excellent!'
                     ' Friday, 21 was especially good!',
               [('2014', datetime.datetime(2014, datetime.datetime.today().month, datetime.datetime.today().day, 0, 0)),
-               ('November', datetime.datetime(2014, 11, datetime.datetime.today().day, 0, 0)),
-               ('Friday, 21', datetime.datetime(2014, 11, 21, 0, 0))]),
+               ('October', datetime.datetime(2014, 10, datetime.datetime.today().day, 0, 0)),
+               ('Friday, 21', datetime.datetime(2014, 10, 21, 0, 0))]),
 
         # Russian
         param('ru', '19 марта 2001 был хороший день. 20 марта тоже был хороший день. 21 марта был отличный день.',
@@ -648,12 +648,49 @@ class TestTranslateSearch(BaseTestCase):
         param(text='Привет',
               languages=['en'],
               settings=None,
-              expected=None)
+              expected=None),
+
+        # ZeroDivisionError
+        param(text='01.09 – 03.09.2017',
+              languages=None,
+              settings={'STRICT_PARSING': True},
+              expected=[('03.09.2017', datetime.datetime(2017, 3, 9, 0, 0))]),
+        param(text="DECEMBER 21 19.87 87",
+              languages=None,
+              settings=None,
+              expected=[('DECEMBER 21 19', datetime.datetime(2019, 12, 21, 0, 0))]
+              ),
+        param(text='bonjour, pouvez vous me joindre svp par telephone 08 11 58 54 41',
+              languages=None,
+              settings={'STRICT_PARSING': True},
+              expected=None),
+        param(text="a Americ",
+              languages=None,
+              settings=None,
+              expected=None),
     ])
     def test_date_search_function(self, text, languages, settings, expected):
         result = search_dates(text, languages=languages, settings=settings)
         self.assertEqual(result, expected)
 
+    @parameterized.expand([
+        param(text="15 de outubro de 1936",
+              add_detected_language=True,
+              expected=[
+                  ("15 de outubro de 1936", datetime.datetime(1936, 10, 15, 0, 0), "pt")
+              ]),
+        param(text="15 de outubro de 1936",
+              add_detected_language=False,
+              expected=[
+                  ("15 de outubro de 1936", datetime.datetime(1936, 10, 15, 0, 0))
+              ]),
+    ])
+    def test_search_dates_returning_detected_languages_if_requested(
+        self, text, add_detected_language, expected
+    ):
+        result = search_dates(text, add_detected_language=add_detected_language)
+        self.assertEqual(result, expected)
+
     @parameterized.expand([
         param(text='19 марта 2001',
               languages='wrong type: str instead of list'),
